# client

## Requirements

Building the API client library requires [Maven](https://maven.apache.org/) to be installed.

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn deploy
```

Refer to the [official documentation](https://maven.apache.org/plugins/maven-deploy-plugin/usage.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
    <groupId>de.uulm.omi.cloudiator.catalogue</groupId>
    <artifactId>client</artifactId>
    <version>1.0.0</version>
    <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "de.uulm.omi.cloudiator.catalogue:client:1.0.0"
```

### Others

At first generate the JAR by executing:

    mvn package

Then manually install the following JARs:

* target/client-1.0.0.jar
* target/lib/*.jar

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

import de.uulm.omi.cloudiator.catalogue.client.*;
import de.uulm.omi.cloudiator.catalogue.client.auth.*;
import de.uulm.omi.cloudiator.dbms.evaluator.model.*;
import de.uulm.omi.cloudiator.catalogue.client.api.ApplicationApi;

import java.io.File;
import java.util.*;

public class ApplicationApiExample {

    public static void main(String[] args) {
        
        ApplicationApi apiInstance = new ApplicationApi();
        String applicationName = "applicationName_example"; // String | maps to the parent application description to identify its application components
        String networkType = "networkType_example"; // String | specifies the network type for the generic application
        java.util.List<Component> components = Arrays.asList(new Component()); // java.util.List<Component> | a list of application components
        try {
            Deployment result = apiInstance.genericPost(applicationName, networkType, components);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling ApplicationApi#genericPost");
            e.printStackTrace();
        }
    }
}

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApplicationApi* | [**genericPost**](docs/ApplicationApi.md#genericPost) | **POST** /generic | Generic application deployment
*BigDataApi* | [**bigdataSparkPost**](docs/BigDataApi.md#bigdataSparkPost) | **POST** /bigdata/spark | deploys an Apache Spark cluster
*BigDataApi* | [**bigdataSparkSparkJobPost**](docs/BigDataApi.md#bigdataSparkSparkJobPost) | **POST** /bigdata/spark/sparkJob | submit an Apache Spark job to a Spark Master
*DatabaseApi* | [**databaseClusterPost**](docs/DatabaseApi.md#databaseClusterPost) | **POST** /database/cluster | DDBMS cluster deployment
*DatabaseApi* | [**databaseCrossClusterPost**](docs/DatabaseApi.md#databaseCrossClusterPost) | **POST** /database/crossCluster | DDBMS cluster deployment
*DatabaseApi* | [**databaseSinglePost**](docs/DatabaseApi.md#databaseSinglePost) | **POST** /database/single | DDBMS cluster deployment
*UtilsApi* | [**utilsDeploymentStateGet**](docs/UtilsApi.md#utilsDeploymentStateGet) | **GET** /utils/deploymentState | Get the state of a specific deployment


## Documentation for Models

 - [Cluster](docs/Cluster.md)
 - [Component](docs/Component.md)
 - [CrossClusterConfiguration](docs/CrossClusterConfiguration.md)
 - [CustomConfiguration](docs/CustomConfiguration.md)
 - [CustomConfigurationItem](docs/CustomConfigurationItem.md)
 - [DataMemory](docs/DataMemory.md)
 - [DatabaseCluster](docs/DatabaseCluster.md)
 - [DatabaseCrossCluster](docs/DatabaseCrossCluster.md)
 - [DatabaseSingle](docs/DatabaseSingle.md)
 - [Deployment](docs/Deployment.md)
 - [Error](docs/Error.md)
 - [IndexMemory](docs/IndexMemory.md)
 - [NodeConfiguration](docs/NodeConfiguration.md)
 - [ReplicationFactor](docs/ReplicationFactor.md)
 - [Resource](docs/Resource.md)
 - [SparkJob](docs/SparkJob.md)
 - [DatabaseDataComponent](docs/DatabaseDataComponent.md)
 - [DatabaseManagementComponent](docs/DatabaseManagementComponent.md)
 - [DatabaseSeedComponent](docs/DatabaseSeedComponent.md)
 - [Node](docs/Node.md)
 - [Requirement](docs/Requirement.md)
 - [SparkMasterComponent](docs/SparkMasterComponent.md)
 - [SparkWorkerComponent](docs/SparkWorkerComponent.md)
 - [VM](docs/VM.md)
 - [CrossDatabaseDataComponent](docs/CrossDatabaseDataComponent.md)
 - [CrossDatabaseSeedComponent](docs/CrossDatabaseSeedComponent.md)


## Documentation for Authorization

All endpoints do not require authorization.
Authentication schemes defined for the API:

## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author



